@@ -1,5 +1,5 @@
 from itertools import accumulate
-from typing import Dict, List
+from typing import List
 
 import pandas as pd
 
@@ -9,9 +9,9 @@ from plotly.subplots import make_subplots
 from magnumapi.geometry.Geometry import Geometry
 from magnumapi.geometry.GeometryFactory import GeometryFactory
 from magnumapi.geometry.roxie.CableDatabase import CableDatabase
+from magnumapi.optimization.DesignVariable import CockpitGeneticDesignVariable, GeneticDesignVariable
 from magnumapi.optimization.GeneticOptimization import RoxieGeneticOptimization
 from magnumapi.optimization.Logger import SCORE_KEYWORD
-from magnumapi.optimization.ObjectiveConfig import ObjectiveConfig
 from magnumapi.optimization.OptimizationConfig import OptimizationConfig
 
 
@@ -29,19 +29,19 @@ class OptimizationCockpitWidget:
     def __init__(self,
                  gen_opt: RoxieGeneticOptimization,
                  config: OptimizationConfig,
-                 optim_input_df: pd.DataFrame,
+                 design_variables_df: pd.DataFrame,
                  cadata: CableDatabase) -> None:
         """ Constructor of an OptimizationCockpitWidget instance
 
         :param gen_opt: genetic optimization instance
         :param config: optimization config instance
-        :param optim_input_df: a dataframe with objective variables
+        :param design_variables_df: a dataframe with objective variables
         :param cadata: a CableDatabase instance
         """
         self.gen_opt = gen_opt
         self.min_logger_df = gen_opt.get_min_fitness_per_generation()
         self.config = config
-        self.optim_input_df = optim_input_df
+        self.design_variables = initialize_design_variables(design_variables_df)
         self.cadata = cadata
 
         fig = make_subplots(
@@ -75,7 +75,7 @@ class OptimizationCockpitWidget:
         index_best = self.min_logger_df.index[-1]
 
         # Display selected generation objective table
-        obj_best_df = self.create_objective_table(index_best)
+        obj_best_df = create_objective_table(self.config, self.min_logger_df, index_best)
         self.display_objective_table(obj_best_df)
 
         # Display fitness function comparison graph
@@ -88,28 +88,28 @@ class OptimizationCockpitWidget:
         self.display_geometry_graph(index_best, row=3, col=2)
 
         # Create callback function
-        def callback(self):
+        def callback(object: "OptimizationCockpitWidget"):
             def update_point(trace, points, selector):
                 index = points.point_inds[0]
 
                 # Update selected generation objective table
-                widget_data = self.widget.data[1]
-                obj_df = self.create_objective_table(index)
+                widget_data = object.widget.data[1]
+                obj_df = create_objective_table(object.config, object.min_logger_df, index)
                 OptimizationCockpitWidget.update_objective_table(widget_data, obj_df)
 
                 # Clear remaining graphs before display
-                self.widget.data = [self.widget.data[0], self.widget.data[1]]
+                object.widget.data = [object.widget.data[0], object.widget.data[1]]
 
                 # Display fitness function comparison graph
-                self.display_fitness_function_comparison_graph(obj_df, obj_best_df, row=1, col=1)
+                object.display_fitness_function_comparison_graph(obj_df, obj_best_df, row=1, col=1)
 
                 # Display design variables graph
-                self.display_design_variables_graph(index, index_best, row=2, col=1)
+                object.display_design_variables_graph(index, index_best, row=2, col=1)
 
                 # Display geometry graph
-                self.display_geometry_graph(index, row=3, col=2)
+                object.display_geometry_graph(index, row=3, col=2)
 
-                self.update_title(index, self.min_logger_df.loc[index, SCORE_KEYWORD])
+                object.update_title(index, object.min_logger_df.loc[index, SCORE_KEYWORD])
 
             return update_point
 
@@ -151,7 +151,7 @@ class OptimizationCockpitWidget:
 
         :param obj_df: a dataframe with information to be displayed
         """
-        obj_trans_df = OptimizationCockpitWidget.transpose_objective_table(obj_df)
+        obj_trans_df = transpose_objective_table(obj_df)
 
         self.widget.add_trace(
             go.Table(
@@ -166,64 +166,6 @@ class OptimizationCockpitWidget:
             ),
             row=1, col=2)
 
-    @staticmethod
-    def get_weight(config_objectives: List[ObjectiveConfig], objective: str) -> float:
-        """ Static method iterating through the list of objective config, finding a matching name and returning
-        corresponding weight.
-
-        :param config_objectives: list of objective configs
-        :param objective: name of an objective variable
-        :return: value of the objective weight
-        """
-        for config_objective in config_objectives:
-            if config_objective.objective == objective:
-                return config_objective.weight
-
-    @staticmethod
-    def get_constraint(config_objectives: List[ObjectiveConfig], objective: str) -> float:
-        """ Static method iterating through the list of objective config, finding a matching name and returning
-        corresponding constraint.
-
-        :param config_objectives: list of objective configs
-        :param objective: name of an objective variable
-        :return: value of the objective constraint
-        """
-        for config_objective in config_objectives:
-            if config_objective.objective == objective:
-                return config_objective.constraint
-
-    def create_objective_table(self, index: int) -> pd.DataFrame:
-        """ Method creating the objective table by extracting weights, constraints, and weighted objectives
-
-        :param index: index of a selected best individual per generation
-        :return: a dataframe representing the selected individual
-        """
-        objectives = [obj.objective for obj in self.config.objectives]
-        obj_df = pd.DataFrame(self.min_logger_df.loc[index, objectives])
-        obj_df = obj_df.rename(columns={obj_df.columns[0]: 'objective'})
-
-        obj_df['weights'] = obj_df.apply(lambda col:
-                                         OptimizationCockpitWidget.get_weight(self.config.objectives, col.name),
-                                         axis=1)
-        obj_df['constraints'] = obj_df.apply(lambda col:
-                                             OptimizationCockpitWidget.get_constraint(self.config.objectives, col.name),
-                                             axis=1)
-        obj_df['objective_weighted'] = obj_df['weights'] * (obj_df['objective'] - obj_df['constraints'])
-
-        return obj_df
-
-    @staticmethod
-    def transpose_objective_table(obj_df: pd.DataFrame) -> pd.DataFrame:
-        """ Static method transposing the objective table for a selected best individual for a generation
-
-        :param obj_df: input objective table
-        :return: transposed input objective table
-        """
-        obj_trans_df = obj_df.T
-        obj_trans_df = obj_trans_df.reset_index()
-        obj_trans_df = obj_trans_df.rename(columns={"index": ""})
-        return obj_trans_df
-
     @staticmethod
     def update_objective_table(widget_data, obj_df: pd.DataFrame) -> None:
         """ Static method updating the objective table
@@ -231,13 +173,14 @@ class OptimizationCockpitWidget:
         :param widget_data: reference to the table widget in the cockpit
         :param obj_df: new objective dataframe
         """
-        obj_trans_df = OptimizationCockpitWidget.transpose_objective_table(obj_df)
+        obj_trans_df = transpose_objective_table(obj_df)
 
         widget_data.cells = dict(
             values=[obj_trans_df[k].tolist() for k in obj_trans_df.columns],
             align="left")
 
-    def display_fitness_function_comparison_graph(self, obj_df: pd.DataFrame,
+    def display_fitness_function_comparison_graph(self,
+                                                  obj_df: pd.DataFrame,
                                                   obj_best_df: pd.DataFrame,
                                                   row=1,
                                                   col=1) -> None:
@@ -279,69 +222,18 @@ class OptimizationCockpitWidget:
         :param row: row index of the graph in the widget (1-based)
         :param col: column index of the graph in the widget (1-based)
         """
-        dv_columns = [col for col in self.min_logger_df.columns if ':' in col]
-        act_gen = self.prepare_row_for_bar_plot(self.min_logger_df.loc[index_act, dv_columns])
-        best_gen = self.prepare_row_for_bar_plot(self.min_logger_df.loc[index_best, dv_columns])
 
-        trace_best = go.Bar(
-            x=best_gen['frac'].values,
-            hovertext=OptimizationCockpitWidget.get_hover_texts(best_gen),
-            y=best_gen['variable'].values,
-            name='Best',
-            orientation='h')
-
-        trace_act = go.Bar(
-            x=act_gen['frac'].values,
-            hovertext=OptimizationCockpitWidget.get_hover_texts(act_gen),
-            y=act_gen['variable'].values,
-            name='Actual',
-            orientation='h')
+        trace_best = self._prepare_bar_plot_with_fraction(index_best, 'Best')
+        trace_act = self._prepare_bar_plot_with_fraction(index_act, 'Actual')
 
         self.widget.add_traces([trace_best, trace_act], rows=row, cols=col)
 
-    def prepare_row_for_bar_plot(self, df: pd.DataFrame) -> pd.DataFrame:
-        """ Prepare a design variable value row for a bar plot display
-
-        :param df: input design variable dataframe
-        :return: formatted dataframe to display on the graph
-        """
-        min_logger_trans_df = pd.DataFrame(df)
-        min_logger_trans_df = min_logger_trans_df.rename(columns={min_logger_trans_df.columns[0]: 'value'})
-
-        def get_dv_parameter(optim_input_df, variable, parameter):
-            block, variable = variable.split(':')
-            block = int(block)
-            return optim_input_df[(optim_input_df['variable'] == variable) &
-                                  (optim_input_df['bcs'] == block)][parameter].values[0]
-
-        min_logger_trans_df['variable_type'] = min_logger_trans_df.apply(
-            lambda col: get_dv_parameter(self.optim_input_df, col.name, 'variable_type'), axis=1)
-        min_logger_trans_df['xl'] = min_logger_trans_df.apply(
-            lambda col: get_dv_parameter(self.optim_input_df, col.name, 'xl'), axis=1)
-        min_logger_trans_df['xu'] = min_logger_trans_df.apply(
-            lambda col: get_dv_parameter(self.optim_input_df, col.name, 'xu'), axis=1)
-        min_logger_trans_df['frac'] = (min_logger_trans_df['value'] - min_logger_trans_df['xl']) / (
-                min_logger_trans_df['xu'] - min_logger_trans_df['xl'])
-        min_logger_trans_df['variable'] = min_logger_trans_df.index
-        return min_logger_trans_df
-
-    @staticmethod
-    def get_hover_texts(df: pd.DataFrame) -> List[str]:
-        """ Method creating a hover text for a graph with objective values
-
-        :param df: a dataframe with objective values (current value, upper, and lower limit)
-        :return: a list of text to be displayed on hover
-        """
-        hovertexts = []
-        for _, row in df.iterrows():
-            if row['variable_type'] == 'float':
-                hovertext = 'value: %.3f, range: [%.3f, %.3f]' % tuple(row[['value', 'xl', 'xu']].values)
-            else:
-                hovertext = 'value: %d, range: [%d, %d]' % tuple(row[['value', 'xl', 'xu']].values)
-
-            hovertexts.append(hovertext)
-
-        return hovertexts
+    def _prepare_bar_plot_with_fraction(self, index: int, name: str) -> go.Bar:
+        return go.Bar(x=prepare_fractions_for_bar_plot(self.design_variables, self.min_logger_df, index),
+                      hovertext=prepare_hover_texts_for_bar_plot(self.design_variables, self.min_logger_df, index),
+                      y=[dv.variable_name for dv in self.design_variables],
+                      name=name,
+                      orientation='h')
 
     def display_geometry_graph(self, index: int, row=3, col=2) -> None:
         """ Method displaying a geometry preview for a selected index.
@@ -359,8 +251,85 @@ class OptimizationCockpitWidget:
 
         go_scatter = Geometry.create_plotly_scatters(geometry.blocks)
 
-        max_number_of_blocks = int(self.optim_input_df[self.optim_input_df['variable'] == 'nco']['xu'].sum())
+        # To avoid plotting issues in case the number of turns
+        max_number_of_blocks = int(sum([dv.xu for dv in self.design_variables if dv.variable_name == 'nco']))
         for i in range(max_number_of_blocks - len(go_scatter)):
             go_scatter.append(go.Scatter(x=[], y=[]))
 
         self.widget.add_traces(go_scatter, rows=row, cols=col)
+
+
+# Testable support functions
+def initialize_design_variables(design_variables_df: pd.DataFrame) -> List[CockpitGeneticDesignVariable]:
+    """ Static method initializing genetic optimization cockpit design variables from a DataFrame
+
+    :param design_variables_df: a DataFrame with design variables
+    :return: a list of design variables
+    """
+    design_variables = []
+    for index, row in design_variables_df.iterrows():
+        design_variables.append(CockpitGeneticDesignVariable(GeneticDesignVariable(**row.to_dict())))
+
+    return design_variables
+
+
+def create_objective_table(config: OptimizationConfig,
+                           min_logger_df: pd.DataFrame,
+                           index: int
+                           ) -> pd.DataFrame:
+    """ Method creating the objective table by extracting weights, constraints, and weighted objectives
+
+    :param config:
+    :param min_logger_df:
+    :param index: index of a selected best individual per generation
+    :return: a dataframe representing the selected individual
+    """
+    objectives = [obj.objective for obj in config.objectives]
+    obj_df = pd.DataFrame(min_logger_df.loc[index, objectives])
+    obj_df = obj_df.rename(columns={obj_df.columns[0]: 'objective'})
+
+    obj_df['weights'] = obj_df.apply(lambda col: config.get_weight(col.name), axis=1)
+    obj_df['constraints'] = obj_df.apply(lambda col: config.get_constraint(col.name), axis=1)
+    obj_df['objective_weighted'] = obj_df['weights'] * (obj_df['objective'] - obj_df['constraints'])
+
+    return obj_df
+
+
+def transpose_objective_table(obj_df: pd.DataFrame) -> pd.DataFrame:
+    """ Static method transposing the objective table for a selected best individual for a generation
+
+    :param obj_df: input objective table
+    :return: transposed input objective table
+    """
+    obj_trans_df = obj_df.T
+    obj_trans_df = obj_trans_df.reset_index()
+    obj_trans_df = obj_trans_df.rename(columns={"index": ""})
+    return obj_trans_df
+
+
+def prepare_fractions_for_bar_plot(design_variables: List[CockpitGeneticDesignVariable],
+                                   min_logger_df: pd.DataFrame,
+                                   index: int
+                                   ) -> List[float]:
+    """ Prepare a list of fractions of design variable values for a bar plot display
+
+    :param design_variables: a list of cockpit design variables
+    :param min_logger_df:
+    :param index:
+    :return: a list of fractions for a bar plot
+    """
+    return [dv.get_fraction(min_logger_df.loc[index, dv.logger_column]) for dv in design_variables]
+
+
+def prepare_hover_texts_for_bar_plot(design_variables: List[CockpitGeneticDesignVariable],
+                                     min_logger_df: pd.DataFrame,
+                                     index: int
+                                     ) -> List[float]:
+    """ Prepare a list of hover texts for a bar plot display
+
+    :param design_variables: a list of cockpit design variables
+    :param min_logger_df:
+    :param index:
+    :return:a list of hover texts for a bar plot
+    """
+    return [dv.get_hover_text(min_logger_df.loc[index, dv.logger_column]) for dv in design_variables]
