@@ -17,25 +17,25 @@ class TestCosThetaBlock(TestCase):
     cadata_file_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
     cadata = CableDatabase.read_cadata(cadata_file_path)
 
-# BLOCK 1
-#     1     1     1            0          0              0        13500     16TIL6B   2 20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    # BLOCK 1
+    #     1     1     1            0          0              0        13500     16TIL6B   2 20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
 
-#  INSUL 1
-#   1 BARE                 0            0 'BARE                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6B       1 16TILG6B     STR11     NB3SN2    BARE    NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    #  INSUL 1
+    #   1 BARE                 0            0 'BARE                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6B       1 16TILG6B     STR11     NB3SN2    BARE    NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_rect_no_insulation_no_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6B', no=1,
-                                                        current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6B',
+                                                        no=1, current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6B'),
                                       insul_def=self.cadata.get_insul_definition('16TIL6B'),
@@ -104,7 +104,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.2595
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(0.0000, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(2.2595, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -119,25 +120,25 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     1            0          0              0        13500     16TILG6   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    # BLOCK 1
+    #     1     1     1            0          0              0        13500     16TILG6   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
 
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_rect_with_insulation_no_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6B', no=1,
-                                                        current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6B',
+                                                        no=1, current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6C'),
                                       insul_def=self.cadata.get_insul_definition('16TIL6C'),
@@ -201,7 +202,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.5595
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(0.1500, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(2.4095, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -216,24 +218,25 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     1           25          0              0        13500     16TILG6   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    # BLOCK 1
+    #     1     1     1           25          0              0        13500     16TILG6   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
 
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_rect_with_insulation_with_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6C', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6C',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6C'),
@@ -295,7 +298,6 @@ class TestCosThetaBlock(TestCase):
                                places=4)
         self.assertAlmostEqual(0.0000, Line.calculate_relative_alpha_angle(area_shift.get_line(0)), places=4)
 
-
         # assert positions - bare
         # Conductor number: 1
         # Part of Block: 1
@@ -310,7 +312,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.4095
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(25.1500, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(2.4095, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -325,23 +328,24 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     1           25          5              0        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     1           25          5              0        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TILG6B         21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6C       1 16TILG6B     STR11     NB3SN2   16TINS2    NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_rect_with_insulation_with_radius_with_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=0.0, nco=1, condname='16TIL6C', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=0.0, nco=1, condname='16TIL6C',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6C'),
@@ -403,7 +407,6 @@ class TestCosThetaBlock(TestCase):
                                                                         block.block_def.radius), places=4)
         self.assertAlmostEqual(0.0000, Line.calculate_relative_alpha_angle(area_shift.get_line(0)), places=4)
 
-
         # assert positions - bare
         # Conductor number: 1
         # Part of Block: 1
@@ -418,7 +421,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 4.5884
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(25.0549, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(4.5884, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -433,20 +437,20 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     1           25          5             10        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'EUROCIRCOL                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TILG6          21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6        1 16TILG6     STR11     NB3SN2    16TINS    NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     1           25          5             10        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'EUROCIRCOL                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TILG6          21.84       2.2595       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6        1 16TILG6     STR11     NB3SN2    16TINS    NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_rect_with_insulation_with_radius_with_phi_with_alpha(self, mock_show=None):
         block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=10.0, nco=1, condname='16TIL6C',
@@ -512,7 +516,6 @@ class TestCosThetaBlock(TestCase):
                                                                         block.block_def.radius), places=4)
         self.assertAlmostEqual(10.0000, Line.calculate_relative_alpha_angle(area_shift.get_line(0)), places=4)
 
-
         # assert positions - bare
         # Conductor number: 1
         # Part of Block: 1
@@ -527,7 +530,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 8.3868
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(24.7279, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(4.5944, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -542,23 +546,24 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     4            0            0            0        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 BARE                 0            0 'BARE                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6D        1 16TOLG78B  STR11     NB3SN2    BARE      NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     4            0            0            0        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 BARE                 0            0 'BARE                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6D        1 16TOLG78B  STR11     NB3SN2    BARE      NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_trapz_no_insulation_no_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6D', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6D',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6D'),
@@ -629,7 +634,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.2594
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(-0.0164, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(1.8781, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -644,23 +650,24 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     4            0            0            0        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     4            0            0            0        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_trapz_with_insulation_no_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6E', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=0, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6E',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6E'),
@@ -726,7 +733,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.4094
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_shift.get_line(0)))
 
         self.assertAlmostEqual(0.1323, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(2.0281, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -741,23 +749,24 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     4           25            0            0        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     4           25            0            0        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_traps_with_insulation_with_radius_no_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6E', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=0.0, alpha_r=0.0, nco=1, condname='16TIL6E',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6E'),
@@ -809,9 +818,13 @@ class TestCosThetaBlock(TestCase):
         # Alph0(1 - 4) = 1.0003
         # Phi0(2 - 3) = 0.0000
         # Alph0(2 - 3) = 0.0000
-        self.assertAlmostEqual(4.9891, round(Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius), 4), places=4)
-        self.assertAlmostEqual(1.0003, round(Line.calculate_relative_alpha_angle(area_ins_shift.get_line(2)), 4), places=4)
-        self.assertAlmostEqual(0.0000, Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius), places=4)
+        self.assertAlmostEqual(4.9891, round(
+            Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius), 4), places=4)
+        self.assertAlmostEqual(1.0003, round(Line.calculate_relative_alpha_angle(area_ins_shift.get_line(2)), 4),
+                               places=4)
+        self.assertAlmostEqual(0.0000,
+                               Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius),
+                               places=4)
         self.assertAlmostEqual(0.0000, Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)), places=4)
 
         # assert positions - bare
@@ -828,7 +841,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 2.4094
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_ins_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_ins_shift.get_line(0)))
 
         self.assertAlmostEqual(25.1333, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(2.0281, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -843,23 +857,24 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     4           25            5            0        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     4           25            5            0        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_trapz_with_insulation_with_radius_with_phi_no_alpha(self, mock_show=None):
-        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=0.0, nco=1, condname='16TIL6E', no=1,
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=0.0, nco=1, condname='16TIL6E',
+                                                        no=1,
                                                         current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
         block = RelativeCosThetaBlock(block_def=block_rel_def,
                                       cable_def=self.cadata.get_cable_definition('16TIL6E'),
@@ -912,9 +927,13 @@ class TestCosThetaBlock(TestCase):
         # Alph0(1 - 4) = 1.0003
         # Phi0(2 - 3) = 5.0000
         # Alph0(2 - 3) = 0.0000
-        self.assertAlmostEqual(10.0199, Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius), places=4)
+        self.assertAlmostEqual(10.0199,
+                               Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius),
+                               places=4)
         self.assertAlmostEqual(1.0003, Line.calculate_relative_alpha_angle(area_ins_shift.get_line(2)), places=4)
-        self.assertAlmostEqual(5.0000, Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius), places=4)
+        self.assertAlmostEqual(5.0000,
+                               Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius),
+                               places=4)
         self.assertAlmostEqual(0.0000, Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)), places=4)
 
         # assert positions - bare
@@ -931,7 +950,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 4.5883
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_ins_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_ins_shift.get_line(0)))
 
         self.assertAlmostEqual(25.0372, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(4.2070, round(area_bare.get_line(3).p1.y, 4), places=4)
@@ -946,20 +966,20 @@ class TestCosThetaBlock(TestCase):
         if mock_show is not None:
             mock_show.assert_called()
 
-# BLOCK 1
-#     1     1     4           25            5           10        13500     16TIL9   2  20     0            0
-#    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
-#  INSUL 1
-#   1 16TINS2           0.15         0.15 'eurocircol                    '
-#  No Name            Radial       Azimut  Comment
-#
-#  CABLE 1
-#   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
-#  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
-#
-# CONDUCTOR 1
-#   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
-#  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
+    # BLOCK 1
+    #     1     1     4           25            5           10        13500     16TIL9   2  20     0            0
+    #    no  type   nco       radius          phi        alpha      current    condname  n1 n2  imag         turn
+    #  INSUL 1
+    #   1 16TINS2           0.15         0.15 'eurocircol                    '
+    #  No Name            Radial       Azimut  Comment
+    #
+    #  CABLE 1
+    #   1 16TOLG78B        21.84       1.8782       2.2595    38          100            3 'EUROCIRCOL 26 STR             '
+    #  No Name            height      width_i      width_o    ns      transp.        degrd  Comment
+    #
+    # CONDUCTOR 1
+    #   1 16TIL6E        1 16TOLG78B  STR11     NB3SN2    16TINS2   NONE      NB3SN                1.9 'eurocircol                    '
+    #  No Name       Type CableGeom.  Strand    Filament  Insul     Trans     QuenchMat.           T_o  Comment
     @patch("matplotlib.pyplot.show")
     def test_get_first_isosceles_trapezium_trapz_with_insulation_with_radius_with_phi_with_alpha(self, mock_show=None):
         block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=10.0, nco=1, condname='16TIL6E',
@@ -1015,9 +1035,13 @@ class TestCosThetaBlock(TestCase):
         # Alph0(1 - 4) = 11.0003
         # Phi0(2 - 3) = 5.0000
         # Alph0(2 - 3) = 10.0000
-        self.assertAlmostEqual(9.9922, Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius), places=4)
+        self.assertAlmostEqual(9.9922,
+                               Line.calculate_positioning_angle(area_ins_shift.get_line(2), block.block_def.radius),
+                               places=4)
         self.assertAlmostEqual(11.0003, Line.calculate_relative_alpha_angle(area_ins_shift.get_line(2)), places=4)
-        self.assertAlmostEqual(5.0000, Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius), places=4)
+        self.assertAlmostEqual(5.0000,
+                               Line.calculate_positioning_angle(area_ins_shift.get_line(0), block.block_def.radius),
+                               places=4)
         self.assertAlmostEqual(10.0000, Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)), places=4)
 
         # assert positions - bare
@@ -1034,7 +1058,8 @@ class TestCosThetaBlock(TestCase):
         # y(4) = 8.3865
 
         area_bare = block.get_bare_isosceles_trapezium(p_ref=area_ins_shift.get_line(0).p1,
-                                                       alpha_ref=Line.calculate_relative_alpha_angle(area_ins_shift.get_line(0)))
+                                                       alpha_ref=Line.calculate_relative_alpha_angle(
+                                                           area_ins_shift.get_line(0)))
 
         self.assertAlmostEqual(24.7954, round(area_bare.get_line(3).p1.x, 4), places=4)
         self.assertAlmostEqual(4.2190, round(area_bare.get_line(3).p1.y, 4), places=4)
